/*****************************************************************************
 * Copyright 2013 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbtool.installer;

import com.celum.dbtool.step.DbStep;
import com.celum.dbtool.step.StepType;

/**
 * You will extend from this class when you wish
 * to implement your own step-executor and your
 * implementation register into {@link DbInstaller} then
 *
 * @see SqlExecutor
 * @see JavaExecutor
 * @see GroovyExecutor
 */
public abstract class Executor
{
    /** type for which the executor belong */
    private final StepType type;

    /**
     * Constructor
     */
    protected Executor(StepType type)
    {
        this.type = type;
    }

    /**
     * returns type for which is executor registered
     */
    public StepType getType()
    {
        return type;
    }

    /**
     * here you will implement execution of {@link DbStep step}.
     */
    public abstract void execute(DbStep step);
}
