/*****************************************************************************
 * Copyright 2013 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbtool.installer;

import com.celum.dbtool.step.DbStep;
import com.celum.dbtool.step.JavaStep;
import com.celum.dbtool.step.StepType;

import javax.sql.DataSource;
import java.sql.Connection;
import java.util.Map;

/**
 * This implementation executes the Java steps.
 */
public class JavaExecutor extends Executor
{
    /** holds all variables with values */
    private final Map<String, Object> variables;

    /** database connection */
    private final DataSource dataSource;


    /**
     * Constructor
     */
    protected JavaExecutor(DataSource dataSource, Map<String, Object> variables)
    {
        super(StepType.JAVA);
        this.variables = variables;
        this.dataSource = dataSource;
    }


    /**
     * {@inheritDoc}
     * @param step
     */
    @Override
    public void execute(DbStep step)
    {
        if (step instanceof JavaStep) {
            ((JavaStep) step).invoke(dataSource, variables);
        }
    }
}
