/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbtool.resource;

import com.celum.dbtool.step.*;

import java.io.File;
import java.util.Collection;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

/**
 * Implementation of {@link DbStepResource resource} which loads steps
 * from given directory.
 *
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
public class DirResource extends DbStepResource
{
	/** points to directory where are SQL scripts */
	private final File dir;


	/**
	 * Constructor
	 * @param dir
	 */
	public DirResource(File dir)
	{
		this.dir = dir;
	}


	/**
	 * reads all step files inside directory, sort them and return
	 * them as a collection of sql steps
	 * @return
	 */
	@Override
	public List<DbStep> getSteps()
	{
		if (dir == null) {
			throw new IllegalStateException("Configuration error. Please define a steps-directory for that goal in your pom.xml");
		}

		File[] steps = dir.listFiles();
		if (steps == null) {
			throw new IllegalStateException("non-existing or empty folder " + dir.toString());
		}

		List<DbStep> out = new LinkedList<DbStep>();
		for (int i = 0; i < steps.length; ++i) {
			if (steps[i].isFile()) {
                Version v = Version.of(steps[i].getName());
                StepType type = StepType.getTypeOfFile(steps[i].getName());
                if (type != StepType.UNSUPPORTED && type != StepType.JAVA) {
				    DbStep step = new FileStep(steps[i], v, type);
				    out.add(step);
                }
			}
		}

		return out;
	}
}
