/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbtool.resource;

import com.celum.dbtool.step.DbStep;
import com.celum.dbtool.step.VersionFactory;

import java.util.Collection;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

/**
 * provide access to DB steps loaded directly in memory. This is useful
 * mostly for testing purpose when you could mock your steps.
 *
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
public class MemoryResource extends DbStepResource
{
	/** holds SQL Scripts */
	private final List<DbStep> steps;


	/**
	 * Constructor
	 */
	public MemoryResource()
	{
        steps = new LinkedList<DbStep>();
	}


    /**
     * Constructor
     */
    public MemoryResource(DbStep script)
    {
        this();
        steps.add(script);
    }


    /**
	 * Constructor
	 */
	public MemoryResource(List<DbStep> steps)
	{
		this.steps = steps;
	}


	/**
	 * adds sql step into in-memory holder
	 *
	 * @param step
	 * @return
	 */
	public MemoryResource addStep(DbStep step)
	{
		this.steps.add(step);
		return this;
	}

    /**
     * adds steps into in-memory holder
     *
     * @param step
     * @return
     */
    public MemoryResource addSteps(DbStep... step)
    {
        for (int i = 0; i < step.length; ++i) {
            this.steps.add(step[i]);
        }
        return this;
    }


	/**
	 * returns SQL scripts hold by this resource
	 * @return
	 */
	@Override
	public List<DbStep> getSteps()
	{
		return steps;
	}
}
