/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbtool.step;

import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;

/**
 * This implementation load step from classpath.
 *
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
public class ClasspathStep extends DbStep
{
    private final String pathToStep;
    private final ClassLoader loader;


    /**
     * simple constructor
     * @param v
     * @param script
     */
    public ClasspathStep(Version v, String script)
    {
        this(script, v, StepType.getTypeOfFile(script), script );
    }


    /**
     * Constructor
     */
    public ClasspathStep(String name, Version v, StepType type, String pathToStep)
    {
        this(name, v, type, pathToStep, ClassLoader.getSystemClassLoader());
    }


    /**
     * Constructor
     */
    public ClasspathStep(String name, Version v, StepType type, String pathToStep, ClassLoader loader)
    {
        super(name, v, type);
        this.pathToStep = pathToStep;
        this.loader = loader;
    }



    /**
     * {@inheritDoc}
     */
    @Override
    public Reader getStepReader()
    {
        InputStream is = loader.getResourceAsStream(pathToStep);
        return new InputStreamReader(is);
    }
}
