/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbtool.step;

/**
 * simple number version implementation.
 *
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
public class LongVersion extends Version {

    /** holds the version nr. */
    public final long versionId;

    /**
     * Constructor
     */
    public LongVersion(long versionId)
    {
        this.versionId = versionId;
    }

    @Override
    public String toString()
    {
        return Long.toString(versionId);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int hashCode()
    {
        return (int) (versionId ^ (versionId >>> 32));
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int compareTo(Version v)
    {
        if (v instanceof LongVersion) {
            LongVersion that = (LongVersion) v;
            if (this.versionId == that.versionId) {
                return 0;
            } else if (this.versionId < that.versionId) {
                return -1;
            } else if (this.versionId > that.versionId) {
                return 1;
            }
        }
        throw new IllegalArgumentException("The compared versions are " + this.getClass().getCanonicalName() + " and " + v.getClass().getCanonicalName() + " and cannot be compared");
    }
}
